@@ -4,18 +4,16 @@
 # Distributed under the terms of the Modified BSD License.
 import json
 import os
-
 from glob import glob
+
 import json5
-from jsonschema import ValidationError
 from jsonschema import Draft4Validator as Validator
+from jsonschema import ValidationError
+from jupyter_server.extension.handler import ExtensionHandlerJinjaMixin, ExtensionHandlerMixin
+from jupyter_server.services.config.manager import ConfigManager, recursive_update
 from tornado import web
 
-from jupyter_server.extension.handler import ExtensionHandlerMixin, ExtensionHandlerJinjaMixin
-from jupyter_server.services.config.manager import ConfigManager, recursive_update
-
-from .server import APIHandler, json_errors, tz
-
+from .server import APIHandler, tz
 
 # The JupyterLab settings file extension.
 SETTINGS_EXTENSION = '.jupyterlab-settings'
@@ -23,8 +21,6 @@ SETTINGS_EXTENSION = '.jupyterlab-settings'
 
 def _get_schema(schemas_dir, schema_name, overrides, labextensions_path):
     """Returns a dict containing a parsed and validated JSON schema."""
-
-
     notfound_error = 'Schema not found: %s'
     parse_error = 'Failed parsing schema (%s): %s'
     validation_error = 'Failed validating schema (%s): %s'
@@ -217,12 +213,18 @@ def _list_settings(schemas_dir, settings_dir, overrides, extension='.json', labe
 
 def _override(schema_name, schema, overrides):
     """Override default values in the schema if necessary."""
-
     if schema_name in overrides:
         defaults = overrides[schema_name]
         for key in defaults:
             if key in schema['properties']:
-                schema['properties'][key]['default'] = defaults[key]
+                new_defaults = schema['properties'][key]['default']
+                # If values for defaults are dicts do a recursive update
+                if isinstance(new_defaults, dict):
+                    recursive_update(new_defaults.copy(), defaults[key])
+                else:
+                    new_defaults = defaults[key]
+
+                schema['properties'][key]['default'] = new_defaults
             else:
                 schema['properties'][key] = dict(default=defaults[key])
 
@@ -261,12 +263,17 @@ def _get_overrides(app_settings_dir):
     """Get overrides settings from `app_settings_dir`."""
     overrides, error = {}, ""
     overrides_path = os.path.join(app_settings_dir, 'overrides.json')
+
+    if not os.path.exists(overrides_path):
+        overrides_path = os.path.join(app_settings_dir, 'overrides.json5')
+
     if os.path.exists(overrides_path):
         with open(overrides_path, encoding='utf-8') as fid:
             try:
-                overrides = json.load(fid)
+                overrides = json5.load(fid)
             except Exception as e:
                 error = e
+
     # Allow `default_settings_overrides.json` files in <jupyter_config>/labconfig dirs
     # to allow layering of defaults
     cm = ConfigManager(config_dir_name="labconfig")
@@ -301,7 +308,7 @@ def get_settings(app_settings_dir, schemas_dir, settings_dir, schema_name="", ov
         The first item is a dictionary with a list of setting if no `schema_name`
         was provided, otherwise it is a dictionary with id, raw, scheme, settings
         and version keys. The second item is a list of warnings. Warnings will
-        either be a list of i) strings with the warning messages or ii) `None`s.
+        either be a list of i) strings with the warning messages or ii) `None`.
     """
     result = {}
     warnings = []
@@ -344,6 +351,7 @@ class SettingsHandler(ExtensionHandlerMixin, ExtensionHandlerJinjaMixin, APIHand
 
     @web.authenticated
     def get(self, schema_name=""):
+        """Get setting(s)"""
         result, warnings = get_settings(
             self.app_settings_dir,
             self.schemas_dir,
@@ -362,6 +370,7 @@ class SettingsHandler(ExtensionHandlerMixin, ExtensionHandlerJinjaMixin, APIHand
 
     @web.authenticated
     def put(self, schema_name):
+        """Update a setting"""
         overrides = self.overrides
         schemas_dir = self.schemas_dir
         settings_dir = self.settings_dir
